utils

package
v0.11.6-202-geb217bca Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2025 License: BSD-3-Clause Imports: 8 Imported by: 0

Documentation

Overview

SPDX-License-Identifier: BSD-3-Clause Copyright (c) 2025, Unikraft GmbH and The KraftKit Authors. Licensed under the BSD-3-Clause License (the "License"). You may not use this file expect in compliance with the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func OpenFromTarOCILayer added in v0.12.0

func OpenFromTarOCILayer(r io.Reader, path string) (io.Reader, error)

OpenFromTarOCILayer returns a reader for the given file from the provided tarball reader.

func PlatformChecksum

func PlatformChecksum(seed string, manifest *ocispec.Platform) (string, error)

PlatformChecksum accepts an input manifest and generates a checksum based on the platform

Types

This section is empty.

Jump to