Documentation
¶
Overview ¶
SPDX-License-Identifier: BSD-3-Clause Copyright (c) 2025, Unikraft GmbH and The KraftKit Authors. Licensed under the BSD-3-Clause License (the "License"). You may not use this file expect in compliance with the License.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func OpenFromTarOCILayer ¶ added in v0.12.0
OpenFromTarOCILayer returns a reader for the given file from the provided tarball reader.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.